pub type InitialPolicyRuleUserEvent = InitialStateEvent<PolicyRuleUserEventContent>;Expand description
An m.policy.rule.user event for creating a room.
Aliased Type
pub struct InitialPolicyRuleUserEvent {
pub content: PolicyRuleUserEventContent,
pub state_key: String,
}Fields
content: PolicyRuleUserEventContentData specific to the event type.
state_key: StringA unique key which defines the overwriting semantics for this piece of room state.
This is often an empty string, but some events send a UserId to show which user the event
affects.
Defaults to the empty string.